@@ -1,5 +1,5 @@
 import warnings
-from elastica import FreeRod, OneEndFixedRod, HelicalBucklingBC
+from elastica import FreeRod, ConstraintBase, OneEndFixedBC, HelicalBucklingBC
 
 warnings.warn(
     "The numba-implementation is included in the default elastica module. Please import without _elastica_numba.",
