@@ -1,4 +1,5 @@
-__doc__ = """ Sphere rigid body class """
+__doc__ = """"""
+__all__ = ["Sphere"]
 
 import numpy as np
 
@@ -9,6 +10,15 @@ from elastica.rigidbody.rigid_body import RigidBodyBase
 
 class Sphere(RigidBodyBase):
     def __init__(self, center, base_radius, density):
+        """
+        Rigid body sphere initializer.
+
+        Parameters
+        ----------
+        center
+        base_radius
+        density
+        """
         # rigid body does not have elements it only have one node. We are setting n_elems to
         # zero for only make code to work. _bootstrap_from_data requires n_elems to be defined
         self.n_elems = 1
